@@ -344,7 +344,9 @@ class MolPDF(object):
         indigo.setOption("render-image-size", 400, 400)
         indigo.setOption("render-background-color", 1.0, 1.0, 1.0)
 
-        path = os.path.join(temporary_directory, smiles + '.png')
+        import uuid
+
+        path = os.path.join(temporary_directory,  str(uuid.uuid4()) + '.png')
 
         renderer.renderToFile(molecule, filename=path)
         image = Image(path, 1 * inch, 1 * inch, hAlign='CENTER')
